# costcalc

*costcalc* is a Python library for calculating the overall raw materials costs 
of a user-defined synthetic route. This package is intended for Python 
versions >= 3.

## Requirements

* Python >= 3
* Numpy >= 1.0
* Pandas >= 1.0
* Matplotlib >= 3.0
* Openpyxl >= 3.0
